pub struct BlendMode {
pub mix: Mix,
pub compose: Compose,
}Expand description
Blend mode consisting of color mixing and composition functions.
Fields
mix: MixThe color mixing function.
compose: ComposeThe layer composition function.
Implementations
Sourceimpl BlendMode
impl BlendMode
Sourcepub const fn new(mix: Mix, compose: Compose) -> Self
pub const fn new(mix: Mix, compose: Compose) -> Self
Creates a new blend mode from color mixing and layer composition functions.
Sourcepub const fn is_destructive(&self) -> bool
pub const fn is_destructive(&self) -> bool
Returns whether this blend mode might cause destructive changes in the backdrop.
Destructive blend modes disallow certain optimizations, such as skipping transparent paints.